primeP, the highest prime number smaller than p and genVec, a d-dimensional generating vector defining an efficient lattice rule for primeP samples.
Arguments
p
number of samples to use in the quasi-Monte Carlo procedure.
d
Dimension of the multivariate integral to estimate.
bt
Tuning parameter for finding the vector. See D. Nuyens and R. Cools (2004) for more details.
gm
Tuning parameter for finding the vector. See D. Nuyens and R. Cools (2004) for more details.
Details
The function computes a generating vector for efficient multivariate integral estimation
based on D. Nuyens and R. Cools (2004). If p is not a prime, the nearest smaller prime is used instead.
References
Nuyens, D. and R. Cools (2004). Fast component-by-component construction, a reprise for different kernels. In Monte Carlo and Quasi-Monte Carlo Methods 2004, H. Niederreiter and D. Talay, eds. Springer: Berlin, 373-87.
#Define the number of sample.p <- 500
#Choose a dimensiond <- 300
#Compute the generating vectorlatticeRule <- genVecQMC(p,d)
print(latticeRule$primeP)
print(latticeRule$genVec)